# InvoiceItemPreviewResultProcessingType

Enum: \"Charge\", \"Discount\", \"Tax\" 

## Enum

* `CHARGE` (value: `'Charge'`)

* `DISCOUNT` (value: `'Discount'`)

* `TAX` (value: `'Tax'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


